==> okteta-0.25.2.tar.xz: okteta-0.25.2/core/tests/piecetablebytearraymodelversionableiftest.cpp <==
/*
    This file is part of the Okteta Core library, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "piecetablebytearraymodelversionableiftest.h"

// test object
#include <piecetablebytearraymodel.h>
// Qt
#include <QTest>

namespace Okteta {
static const Size ByteArrayModelSize = 60;

QObject* PieceTableByteArrayModelVersionableIfTest::createVersionable()
{
    PieceTableByteArrayModel* byteArrayModel = new PieceTableByteArrayModel(ByteArrayModelSize);
    byteArrayModel->setReadOnly(false);

    return byteArrayModel;
}

void PieceTableByteArrayModelVersionableIfTest::deleteVersionable(QObject* versionable)
{
    delete versionable;
}

}

QTEST_GUILESS_MAIN(Okteta::PieceTableByteArrayModelVersionableIfTest)

==> okteta-0.26.0.tar.xz: okteta-0.26.0/core/tests/piecetablebytearraymodelversionableiftest.cpp <==
/*
    This file is part of the Okteta Core library, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "piecetablebytearraymodelversionableiftest.hpp"

// test object
#include <piecetablebytearraymodel.hpp>
// Qt
#include <QTest>

namespace Okteta {

static constexpr Size ByteArrayModelSize = 60;

QObject* PieceTableByteArrayModelVersionableIfTest::createVersionable()
{
    auto* byteArrayModel = new PieceTableByteArrayModel(ByteArrayModelSize);
    byteArrayModel->setReadOnly(false);

    return byteArrayModel;
}

void PieceTableByteArrayModelVersionableIfTest::deleteVersionable(QObject* versionable)
{
    delete versionable;
}

}

QTEST_GUILESS_MAIN(Okteta::PieceTableByteArrayModelVersionableIfTest)
